MmInfoError

Enum MmInfoError 

pub enum MmInfoError {
    OutOfBounds {
        offset: usize,
        length: usize,
        tokens_len: usize,
    },
    OffsetOverflow {
        offset: usize,
        length: usize,
    },
    Overlapping {
        position: usize,
    },
    EmptyRun,
}
Errors raised while validating TokenBlockMmInfo inputs.

Variants



OutOfBounds

The run extends past the end of the token sequence.

Fields

offset: usize

Run start.

length: usize

Run length.

tokens_len: usize

Length of the token sequence the run was validated against.



OffsetOverflow

offset + length overflows usize.

Fields

offset: usize

Run start.

length: usize

Run length.



Overlapping

Two runs overlap.

Fields

position: usize

Position where the overlap begins.



EmptyRun

A run has zero length.