pub type BlockHash = u64;Expand description
A 64-bit hash computed from the tokens within a single block (with optional MM
frames), seeded by the request’s SaltHash.
The canonical construction path is compute_block_hash.
pub type BlockHash = u64;A 64-bit hash computed from the tokens within a single block (with optional MM
frames), seeded by the request’s SaltHash.
The canonical construction path is compute_block_hash.